# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class BuyResponseCapabilities(UniversalBaseModel):
    """
    Enabled communication features for the phone number.
    """

    sms: bool = pydantic.Field()
    """
    Indicates if SMS messaging is enabled and functional.
    """

    mms: bool = pydantic.Field()
    """
    Indicates if multimedia messaging (images, videos, files) is enabled and functional.
    """

    voice: bool = pydantic.Field()
    """
    Indicates if voice calling is enabled and functional.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
