# This file was auto-generated by Fern from our API Definition.

import typing

RcsCampaignUseCaseEnum = typing.Union[
    typing.Literal[
        "ADVERTISING_MARKETING",
        "ARTS_AND_ENTERTAINMENT",
        "BFSI",
        "COMMERCIAL_AND_INDUSTRIAL",
        "COMMUNITY_ORGANIZATIONS",
        "CREDIT_RATING",
        "DELIVERY_PARTNER",
        "EDUCATION",
        "FINANCE",
        "FOOD_AND_BEVERAGE",
        "GAMING",
        "GOVERNMENT",
        "HEALTH",
        "HOTEL_AND_BNB",
        "INSURANCE",
        "LEGAL",
        "LENDING",
        "LOANS",
        "LOCAL_SERVICES",
        "NEWS",
        "NON_GOVERNMENTAL_ORGANIZATIONS",
        "NON_PROFIT_ORGANIZATIONS",
        "ONLINE_SELLER",
        "OTHER",
        "PRODUCTIVITY",
        "PROPERTY",
        "SCIENCE_TECHNOLOGY_ENGINEERING",
        "SHOPPING_AND_RETAIL",
        "SOCIAL",
        "SPORTS",
        "TELECOMMUNICATIONS",
        "TRAVEL",
        "UTILITIES",
    ],
    typing.Any,
]
